from toml import TomlDecodeError
from discord import Bot, Intents

from config import Config
from logger import Logger
from framework import Redis
from cogs import Greetings


if __name__ == "__main__":
    # Read Config
    try:
        config = Config("config.toml")
        print(config)
    except TomlDecodeError as error:
        print("Config/DecodeError : %s" % error)
        exit(1)
    except KeyError as error:
        print("Config/KeyError : %s" % error)
        exit(2)

    # Set Logger
    logger = Logger(config.logging)()

    # Redis Client
    redis = Redis(config.redis)

    # Bot
    intents = Intents.default()
    bot = Bot(intents=intents)
    bot.add_cog(Greetings(bot, logger, redis))
    bot.run(config.discord.token)
